@@ -2,11 +2,11 @@ plot.rdela <-
 function (x,...) 
 {
 
-require(rgl)
+# require(rgl)
 
 
 if(dim(x$data)[2]==2){
-	x11()
+	dev.new()
 	plot(x$data,asp=1,xlab=expression(data[x]),ylab=expression(data[y]))
 	symbols(x=x$center[1,],y=x$center[2,],circles=x$radii,fg="grey",inches=F,add=T)
 	apply(x$tri,1,function(y) lines(x$data[c(y,y[1]),]))
@@ -21,7 +21,7 @@ if(dim(x$data)[2]==3){
 	points3d(x$data[unique(as.vector(x$tri[x$LiB[[which.max(x$GeB)]],])),],col="red",size=5)
 	}
 
-x11()
+dev.new()
 plot(mahalanobis(x$data,center=colMeans(x$data[x$drin,]),cov=cov(x$data[x$drin,])),ylab="Mahalanobis distance",xlab="Index")
 points(x$drin,mahalanobis(x$data,center=colMeans(x$data[x$drin,]),cov=cov(x$data[x$drin,]))[x$drin],col="red")
 
